##  Choosing a Feature for Updating Fact Sheet Fields
You can use both calculations and automations for updating fact sheet fields.
  * Use calculations to:
    * Update a target fact sheet field automatically.
    * Prevent manual updates to the field (it will be displayed as read-only).
  * Use automations to:
    * Define rules for updating one or more fact sheet fields.
    * Include additional actions in a workflow.
    * Allow manual updates of target fields.
